==> js_ui_components-0.0.1.tar.gz: lib/src/widgets/js_list_view.dart <==
library js_list_view;

import 'package:flutter/material.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

import 'js_progress.dart';

class JsListView extends StatelessWidget {
  final _refreshController = RefreshController(initialRefresh: false);
  final int itemCount;
  final Widget emptyState;
  final Widget loadingWidget;
  final bool loading;
  final bool shrinkWrap;
  final EdgeInsetsGeometry padding;
  final ScrollPhysics physics;
  final IndexedWidgetBuilder itemBuilder;
  final dynamic models;
  final bool enablePullDown;
  final Function onRefresh;

  JsListView({
    Key key,
    @required this.itemBuilder,
    this.emptyState,
    this.itemCount,
    this.models,
    this.loading,
    this.padding,
    this.physics,
    this.shrinkWrap = false,
    this.loadingWidget,
    this.enablePullDown,
    this.onRefresh,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    int itemCount = _getItemCount();

    if (loading != null && loading) {
      return loadingWidget ?? Center(child: JsProgress());
    }

    if ((itemCount == null || itemCount == 0) && emptyState != null) {
      return emptyState;
    }

    return SmartRefresher(
      enablePullDown: _getEnablePullDown(),
      controller: _refreshController,
      onRefresh: () async {
        _refreshController.resetNoData();
        // monitor network fetch
        if (onRefresh != null) {
          await onRefresh();
        }

        _refreshController.refreshCompleted();
      },
      child: ListView.builder(
        physics: physics,
        shrinkWrap: shrinkWrap,
        padding: padding,
        itemCount: itemCount,
        itemBuilder: itemBuilder,
      ),
    );
  }

  int _getItemCount() {
    if (itemCount != null) {
      return itemCount;
    }

    if (models is List) {
      return models.length;
    }

    return 0;
  }

  bool _getEnablePullDown() {
    if (enablePullDown != null) {
      return enablePullDown;
    }

    if (onRefresh != null) {
      return true;
    }

    return false;
  }
}

==> js_ui_components-0.0.3.tar.gz: lib/src/widgets/js_list_view.dart <==
import 'package:flutter/material.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

import 'js_progress.dart';

class JsListView extends StatelessWidget {
  final _refreshController = RefreshController(initialRefresh: false);
  final int? itemCount;
  final Widget? emptyState;
  final Widget? loadingWidget;
  final Widget? header;
  final bool? loading;
  final bool shrinkWrap;
  final EdgeInsetsGeometry? padding;
  final ScrollPhysics? physics;
  final IndexedWidgetBuilder itemBuilder;
  final dynamic models;
  final bool? enablePullDown;
  final Function? onRefresh;
  final bool reverse;

  JsListView({
    Key? key,
    required this.itemBuilder,
    this.emptyState,
    this.itemCount,
    this.models,
    this.loading,
    this.padding,
    this.physics,
    this.shrinkWrap = false,
    this.loadingWidget,
    this.enablePullDown,
    this.onRefresh,
    this.header,
    this.reverse = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    int itemCount = _getItemCount();

    if (header != null) {
      itemCount++;
    }

    if (loading != null && loading!) {
      return loadingWidget ?? Center(child: JsProgress());
    }

    if ((itemCount == null || itemCount == 0) && emptyState != null) {
      return emptyState!;
    }

    return SmartRefresher(
      enablePullDown: _getEnablePullDown()!,
      controller: _refreshController,
      onRefresh: () async {
        _refreshController.resetNoData();
        // monitor network fetch
        if (this.onRefresh != null) {
          await this.onRefresh!();
        }

        _refreshController.refreshCompleted();
      },
      child: ListView.builder(
        physics: physics,
        reverse: reverse,
        shrinkWrap: shrinkWrap,
        padding: padding,
        itemCount: itemCount,
        itemBuilder: (_, index) {
          if (header != null && index == 0) {
            return header!;
          }

          return itemBuilder(_, index - (header == null ? 0 : 1));
        },
      ),
    );
  }

  int _getItemCount() {
    if (itemCount != null) {
      return itemCount!;
    }

    if (models is List) {
      return models?.length ?? 0;
    }

    return 0;
  }

  bool? _getEnablePullDown() {
    if (enablePullDown != null) {
      return enablePullDown;
    }

    if (this.onRefresh != null) {
      return true;
    }

    return false;
  }
}
